#ifndef MAIL_STORAGE_H

#define MAIL_STORAGE_H

#ifdef __cplusplus
extern "C" {
#endif

#include "maildriver.h"

#include <inttypes.h>

#include "mailstorage_types.h"
#include "imapstorage.h"
#include "mboxstorage.h"
#include "mhstorage.h"
#include "nntpstorage.h"
#include "pop3storage.h"



/* storage */

/*
  mail_storage_new

  This function creates an empty storage. This storage have to be initialized.
  The "driver" and "data" fields should be initialized.

  @param id  is the name of the storage. It can be NULL.
    The given parameter is no more needed when the creation is finished.
    The given string is duplicated.

  @return The mail storage is returned.
*/

struct mail_storage * mail_storage_new(char * id);

void mail_storage_free(struct mail_storage * storage);

/*
  session will be initialized on success.
*/

int mail_storage_connect(struct mail_storage * storage);

void mail_storage_disconnect(struct mail_storage * storage);


/* folder */

struct mail_folder * mail_folder_new(struct mail_storage * storage,
    char * pathname, char * virtual_name);

void mail_folder_free(struct mail_folder * folder);

int mail_folder_add_child(struct mail_folder * parent,
        struct mail_folder * child);

int mail_folder_detach_parent(struct mail_folder * folder);

int mail_folder_connect(struct mail_folder * folder);

void mail_folder_disconnect(struct mail_folder * folder);


/*
  this is the type of socket connection
*/

enum {
  CONNECTION_TYPE_PLAIN,        /* when the connection is plain text */
  CONNECTION_TYPE_STARTTLS,     /* when the connection is first plain,
                                   then, we want to switch to
                                   TLS (secure connection) */
  CONNECTION_TYPE_TRY_STARTTLS, /* the connection is first plain,
                                   then, we will try to switch to TLS */
  CONNECTION_TYPE_TLS,          /* the connection is over TLS */
};


#ifdef __cplusplus
}
#endif

#endif


