#ifndef NNTPSTORAGE_H

#define NNTPSTORAGE_H

#ifdef __cplusplus
extern "C" {
#endif

#include "mailstorage.h"


/* nntp storage */

/*
  nntp_mail_storage is the state data specific to the IMAP4rev1 storage.

  - storage this is the storage to initialize.

  - servername  this is the name of the NNTP server
  
  - port is the port to connect to, on the server.
    you give 0 to use the default port.

  - connection_type is the type of socket layer to use.
    The value can be CONNECTION_TYPE_PLAIN or CONNECTION_TYPE_TLS.
    
  - auth_type is the authenticate mechanism to use.
    The value can be NNTP_AUTH_TYPE_PLAIN.

  - login is the login of the POP3 account.

  - password is the password of the POP3 account.

  - cached if this value is != 0, a persistant cache will be
    stored on local system.

  - cache_directory is the location of the cache

  - flags_directory is the location of the flags
*/

struct nntp_mail_storage {
  char * servername;
  uint16_t port;
  int connection_type;

  int auth_type;
  char * login;
  char * password;

  int cached;
  char * cache_directory;
  char * flags_directory;
};

/* this is the type of POP3 authentication */

enum {
  NNTP_AUTH_TYPE_PLAIN,  /* plain text authentication */
};

/*
  nntp_mail_storage_init is the constructor for a NNTP storage

  @param storage this is the storage to initialize.

  @param servername  this is the name of the NNTP server
  
  @param port is the port to connect to, on the server.
    you give 0 to use the default port.

  @param connection_type is the type of socket layer to use.
    The value can be CONNECTION_TYPE_PLAIN or CONNECTION_TYPE_TLS.
    
  @param auth_type is the authenticate mechanism to use.
    The value can be NNTP_AUTH_TYPE_PLAIN.

  @param login is the login of the POP3 account.

  @param password is the password of the POP3 account.

  @param cached if this value is != 0, a persistant cache will be
    stored on local system.

  @param cache_directory is the location of the cache

  @param flags_directory is the location of the flags
*/

int nntp_mail_storage_init(struct mail_storage * storage,
    char * servername, uint16_t port,
    int connection_type, int auth_type,
    char * login, char * password,
    int cached, char * cache_directory, char * flags_directory);

#ifdef __cplusplus
}
#endif

#endif
