#ifndef POP3STORAGE_H

#define POP3STORAGE_H

#ifdef __cplusplus
extern "C" {
#endif

#include "mailstorage.h"

/* pop3 storage */

/*
  pop3_mail_storage is the state data specific to the POP3 storage.

  - servername  this is the name of the POP3 server

  - port is the port to connect to, on the server.
      you give 0 to use the default port.

  - connection_type is the type of socket layer to use.
      The value can be CONNECTION_TYPE_PLAIN, CONNECTION_TYPE_STARTTLS,
      CONNECTION_TYPE_TRY_STARTTLS or CONNECTION_TYPE_TLS.
    
  - auth_type is the authenticate mechanism to use.
      The value can be POP3_AUTH_TYPE_PLAIN, POP3_AUTH_TYPE_APOP
      or POP3_AUTH_TYPE_TRY_APOP. Other values are not yet implemented.

  - login is the login of the POP3 account.

  - password is the password of the POP3 account.

  - cached if this value is != 0, a persistant cache will be
      stored on local system.
  
  - cache_directory is the location of the cache.

  - flags_directory is the location of the flags.
*/

struct pop3_mail_storage {
  char * servername;
  uint16_t port;
  int connection_type;

  int auth_type;
  char * login;
  char * password;

  int cached;
  char * cache_directory;
  char * flags_directory;
};

/* this is the type of POP3 authentication */

enum {
  POP3_AUTH_TYPE_PLAIN,             /* plain text authentication */
  POP3_AUTH_TYPE_APOP,              /* APOP authentication */
  POP3_AUTH_TYPE_TRY_APOP,          /* first, try APOP, if it fails,
                                       try plain text */
  POP3_AUTH_TYPE_SASL_ANONYMOUS,    /* SASL anonymous */
  POP3_AUTH_TYPE_SASL_CRAM_MD5,     /* SASL CRAM MD5 */
  POP3_AUTH_TYPE_SASL_KERBEROS_V4,  /* SASL KERBEROS V4 */
  POP3_AUTH_TYPE_SASL_PLAIN,        /* SASL plain */
  POP3_AUTH_TYPE_SASL_SCRAM_MD5,    /* SASL SCRAM MD5 */
  POP3_AUTH_TYPE_SASL_GSSAPI,       /* SASL GSSAPI */
  POP3_AUTH_TYPE_SASL_DIGEST_MD5,   /* SASL digest MD5 */
};

/*
  pop3_mail_storage_init is the constructor for a POP3 storage

  @param storage this is the storage to initialize.

  @param servername  this is the name of the POP3 server
  
  @param port is the port to connect to, on the server.
    you give 0 to use the default port.

  @param connection_type is the type of socket layer to use.
    The value can be CONNECTION_TYPE_PLAIN, CONNECTION_TYPE_STARTTLS,
    CONNECTION_TYPE_TRY_STARTTLS or CONNECTION_TYPE_TLS.
    
  @param auth_type is the authenticate mechanism to use.
    The value can be POP3_AUTH_TYPE_PLAIN, POP3_AUTH_TYPE_APOP
    or POP3_AUTH_TYPE_TRY_APOP. Other values are not yet implemented.

  @param login is the login of the POP3 account.

  @param password is the password of the POP3 account.

  @param cached if this value is != 0, a persistant cache will be
    stored on local system.

  @param cache_directory is the location of the cache

  @param flags_directory is the location of the flags
*/

int pop3_mail_storage_init(struct mail_storage * storage,
    char * servername, uint16_t port,
    int connection_type, int auth_type,
    char * login, char * password,
    int cached, char * cache_directory, char * flags_directory);

#ifdef __cplusplus
}
#endif

#endif
